export interface IBaseConfig {
    libName: string;
    libDesc: string;
    hasDemo: boolean;
    hasTest: boolean;
    hasTsLint: boolean;
    isExecutable: boolean;
    author: string;
    license: 'MIT' | 'GNU' | 'Apache' | 'other';
    testRunner: 'jest';
    dependencyManager: 'yarn';
}
export interface IBundlerConfig extends IBaseConfig {
    compileMethod: 'bundler';
    bundler: 'webpack';
}
export interface ITscConfig extends IBaseConfig {
    compileMethod: 'tsc';
    tsCompileModule: 'commonjs' | 'es6';
}
export declare type IConfig = IBundlerConfig | ITscConfig;
export declare function copyTemplatesFile(filePath: string, options?: {
    rename?: string;
    sedMap?: {
        [key: string]: string;
    };
}): void;
export declare function addBundlerPackageJson(runtimeConfig: IBundlerConfig): void;
export declare function addTscPackageJson(runtimeConfig: ITscConfig): void;
/**
 * Add package.json file based on config
 */
export declare function addPackageJson(runtimeConfig: IConfig): void;
export declare function addSourceCode(runtimeConfig: IConfig): void;
export declare function addTestCodeForBundler(runtimeConfig: IBundlerConfig): void;
export declare function addTestCodeForTsc(runtimeConfig: ITscConfig): void;
export declare function addTestCode(runtimeConfig: IConfig): void;
export declare function addBundler(runtimeConfig: IBundlerConfig): void;
export declare function getPackageJson(): any;
export declare function setPackageJson(packageJson: object): void;
export declare function updatePackageJson(callback: (packageJson: any) => object): void;
export declare function askRuntimeConfig(): Promise<IConfig>;
export declare function main(runtimeConfig?: IConfig): Promise<void>;
